EvmSelectors

Struct EvmSelectors 

pub struct EvmSelectors { /* private fields */ }

Implementations

Source

impl EvmSelectors

pub async fn download(timeout: Option<Duration>) -> Result<String>

Downloads the latest known selectors from the OpenChain API. The result is returned as string and not persisted. Note that the download speed can differ significantly, from seconds to an hour or more. A timeout can be specified to limit the time the request is allowed to take.

Errors

This function will return an error if the HTTP request fails.

pub async fn download_to_file( path: &Path, timeout: Option<Duration>, ) -> Result<()>

Downloads the latest known selectors from the OpenChain API and persists them to the file at path. If the file exists, it will be overwritten. The directory structure will be created if it does not exist. Note that the download speed can differ significantly, from seconds to an hour or more. A timeout can be specified to limit the time the request is allowed to take.

Errors

This function will return an error if the HTTP request fails, or if writing to the file fails.

Source

impl EvmSelectors

pub fn new_from_file(path: &Path) -> Result<Self>

Creates a new instance with raw data supplied by the file at path. The data must follow the format as exported by the OpenChain API.

Errors

This function will return an error if reading the file fails or if it contains invalid data.

pub fn new_from_raw(raw: &str) -> Result<Self>

Creates a new instance with raw data supplied by the string raw. The data must follow the format as exported by the OpenChain API.

Errors

This function will return an error if reading the file fails or if it contains invalid data.

pub fn items(&self) -> &HashMap<Selector, Vec<Function>>

Returns all known selectors.

pub fn get(&self, selector: &Selector) -> Option<&Vec<Function>>

Returns the functions known for the given selector. Note that since (especially 4-byte selectors) can have collisions, there can be multiple items returned. It is up to the caller to decide which one to use.

pub fn push(&mut self, selector: Selector, function: Function)

Adds a new item for a given selector. This method does not check for duplicates. The item is purely kept in memory and not persisted.