pub struct EvmSelectors { /* private fields */ }Implementations
Sourceimpl EvmSelectors
impl EvmSelectors
Sourcepub async fn download(timeout: Option<Duration>) -> Result<String>
pub async fn download(timeout: Option<Duration>) -> Result<String>
Downloads the latest known selectors from the OpenChain API. The result is returned as string and not persisted. Note that the download speed can differ significantly, from seconds to an hour or more. A timeout can be specified to limit the time the request is allowed to take.
Errors
This function will return an error if the HTTP request fails.
Sourcepub async fn download_to_file(
path: &Path,
timeout: Option<Duration>,
) -> Result<()>
pub async fn download_to_file( path: &Path, timeout: Option<Duration>, ) -> Result<()>
Downloads the latest known selectors from the OpenChain API and persists them to the file at path.
If the file exists, it will be overwritten. The directory structure will be created if it does not exist.
Note that the download speed can differ significantly, from seconds to an hour or more.
A timeout can be specified to limit the time the request is allowed to take.
Errors
This function will return an error if the HTTP request fails, or if writing to the file fails.
Sourceimpl EvmSelectors
impl EvmSelectors
Sourcepub fn new_from_file(path: &Path) -> Result<Self>
pub fn new_from_file(path: &Path) -> Result<Self>
Creates a new instance with raw data supplied by the file at path.
The data must follow the format as exported by the OpenChain API.
Errors
This function will return an error if reading the file fails or if it contains invalid data.
Sourcepub fn new_from_raw(raw: &str) -> Result<Self>
pub fn new_from_raw(raw: &str) -> Result<Self>
Creates a new instance with raw data supplied by the string raw.
The data must follow the format as exported by the OpenChain API.
Errors
This function will return an error if reading the file fails or if it contains invalid data.